% batchbp.m 
%
% function [W1,B1,W2,B2,yT,MSE] = batchbp2(W1,B1,W2,B2,xT,dT,mu,N)
%
% batch bp with "delta-bar-delta"

function [W1,B1,W2,B2,yT,MSE] = batchbp2(W1,B1,W2,B2,xT,dT,mu,N)

  
[Ni,Np] = size(xT);
[No,Np] = size(dT);

lrw1 		= mu*ones(size(W1));
lrw2		= mu*ones(size(W2));
lrb1		= mu*ones(size(B1));
lrb2		= mu*ones(size(B2));
im			= 1.2;		% increase factor for learningrate
dm			= 0.8;		% decrease factor for learningrate
max_mu	= 3;				% maximum learningrate

ddW1old=ones(size(W1));
ddW2old=ones(size(W2));
ddB1old=ones(size(B1));
ddB2old=ones(size(B2));

%mu = mu/Np;

inp = xT;
des = dT;
MSE = zeros(1,N);

for i = 1:N;

a0 = inp;
a1 = tanh(W1*a0 + B1*ones(1,Np));
a2 = (W2*a1 + B2*ones(1,Np));
out = a2;

e = -2 * (des-out);

MSE(i) = sum(sum( (des-out) .* (des-out) )) /Np;

d2 = e;
d1 = (W2' * d2).* (1-a1.^2);



ddW1 =  d1 *a0';
ddB1 =  d1 * ones(1,Np)';
ddW2 =  d2 *a1';
ddB2 =  d2 * ones(1,Np)';


MaxW1 = sqrt(max(max(ddW1.*ddW1)));
MaxW2 = sqrt(max(max(ddW2.*ddW2)));
MaxB2 = sqrt(max(max(ddB2.*ddB2)));
MaxB1 = sqrt(max(max(ddB1.*ddB1)));


W1 = W1 - lrw1.*ddW1/MaxW1;	
W2 = W2 - lrw2.*ddW2/MaxW2;	
B1 = B1 - lrb1.*ddB1/MaxB1;	
B2 = B2 - lrb2.*ddB2/MaxB2;	

   % ADAPTIVE LEARNING RATE
   
   % + = Same sign on gradient
        w1x=sign(ddW1old.*ddW1);   
        w2x=sign(ddW2old.*ddW2);
 	b1x=sign(ddB1old.*ddB1);
 	b2x=sign(ddB2old.*ddB2);
    
   % Calculate new learning rates, that will be used the next iteration
 	lrw1=(im*(w1x>0)+dm*(w1x<0)).*lrw1;
 	lrw2=(im*(w2x>0)+dm*(w2x<0)).*lrw2;
 	lrb1=(im*(b1x>0)+dm*(b1x<0)).*lrb1;
 	lrb2=(im*(b2x>0)+dm*(b2x<0)).*lrb2;
    
   % Make sure the learningrates doesnt increase over max_mu
 	lrw1=(ones(size(lrw1))-(lrw1>max_mu)*0.5).*lrw1;
 	lrw2=(ones(size(lrw2))-(lrw2>max_mu)*0.5).*lrw2;
 	lrb1=(ones(size(lrb1))-(lrb1>max_mu)*0.5).*lrb1;
 	lrb2=(ones(size(lrb2))-(lrb2>max_mu)*0.5).*lrb2;
     
 	ddW1old=ddW1;
 	ddW2old=ddW2;
 	ddB1old=ddB1;
 	ddB2old=ddB2;


%disp(sprintf('i = %d MSE = %f',i,MSE(i)));

end;

yT = out;









